starcluster.tests.test_threadpool.TestThreadPool

Package starcluster :: Package tests :: Module test_threadpool :: Class TestThreadPool |
[hide private]
[frames] | no frames]

# Class TestThreadPool

source code

Nested Classes | [hide private]
Inherited from `unittest.TestCase`: `failureException`

Instance Methods | [hide private]
_no_args(self) | source code
_args_only(self, i) | source code
_kwargs_only(self, mykw=None) | source code
_args_and_kwargs(self, i, mykw=None) | source code
test_no_args(self) | source code
test_args_only(self) | source code
test_kwargs_only(self) | source code
test_args_and_kwargs(self) | source code
test_threadpool_map(self) | source code
Inherited from `StarClusterTest`: `get_config`, `get_custom_config` Inherited from `unittest.TestCase`: `__call__`, `__eq__`, `__hash__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `assertAlmostEqual`, `assertAlmostEquals`, `assertEqual`, `assertEquals`, `assertFalse`, `assertNotAlmostEqual`, `assertNotAlmostEquals`, `assertNotEqual`, `assertNotEquals`, `assertRaises`, `assertTrue`, `assert_`, `countTestCases`, `debug`, `defaultTestResult`, `fail`, `failIf`, `failIfAlmostEqual`, `failIfEqual`, `failUnless`, `failUnlessAlmostEqual`, `failUnlessEqual`, `failUnlessRaises`, `id`, `run`, `setUp`, `shortDescription`, `tearDown` Inherited from `unittest.TestCase` (private): `_exc_info` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _jobs = `5`
| _mykw = ``'``StarCluster!!!``'``
| _pool = `None` hash(x)

Properties | [hide private]
| pool
Inherited from `StarClusterTest`: `config` Inherited from `object`: `__class__`

Property Details | [hide private]

### pool Get Method: unreachable.pool(self)